JsonObfuscatorConfig

Struct JsonObfuscatorConfig 

pub struct JsonObfuscatorConfig {
    pub enabled: bool,
    pub keep_keys: HashSet<String>,
    pub transform_keys: HashSet<String>,
    pub transformer: Option<JsonStringTransformer>,
}

Fields

enabled: boolkeep_keys: HashSet<String>

keep_keys will specify a set of keys for which their values will not be obfuscated.

transform_keys: HashSet<String>

transform_keys will specify a set of keys for which their values will be transformed through transformer

transformer: Option<JsonStringTransformer>

transformer is an optional String -> String function which will transform values specified in transform_keys

Implementations

Source

impl JsonObfuscatorConfig

pub fn disabled() -> Self

pub fn enabled() -> Self