Module replacer

Module replacer 

Structs

ReplaceRule

Functions

parse_rules_from_string
parse_rules_from_string takes an array of rules, represented as an array of length 3 arrays holding the tag name, regex pattern, and replacement string as strings.
replace_span_tags
replace_span_tags replaces the tag values of a span with a given set of rules.
replace_trace_tags
replace_trace_tags replaces the tag values of all spans within a trace with a given set of rules.