Module json

Module json 

Structs

JsonObfuscator
Obfuscates a JSON string by replacing all leaf values with "?", unless the value belongs to a key listed in keep_keys, in which case it is left verbatim. Keys in transform_keys have their string values passed through a transformer function (e.g. SQL obfuscation) instead of being replaced with "?".