Structs
- Json
Obfuscator - Obfuscates a JSON string by replacing all leaf values with
"?", unless the value belongs to a key listed inkeep_keys, in which case it is left verbatim. Keys intransform_keyshave their string values passed through a transformer function (e.g. SQL obfuscation) instead of being replaced with"?".