JsonObfuscator

Struct JsonObfuscator 

pub struct JsonObfuscator { /* private fields */ }
Obfuscates a JSON string by replacing all leaf values with "?", unless the value belongs to a key listed in keep_keys, in which case it is left verbatim. Keys in transform_keys have their string values passed through a transformer function (e.g. SQL obfuscation) instead of being replaced with "?".

Multiple concatenated JSON objects in the input are each obfuscated independently. On a parse error the output so far is returned with "..." appended.

Implementations

Source

impl JsonObfuscator

pub fn new( keep_keys: impl IntoIterator<Item = String>, transform_keys: impl IntoIterator<Item = String>, transformer: Option<Box<dyn Fn(&str) -> String + Send + Sync>>, ) -> Self

pub fn obfuscate(&self, input: &str) -> (String, Option<String>)

Obfuscates json string and return an optional error on malformatted json If an error occurs, an value is returned anyways which might be truncated (…)