Structs
Functions
- parse_
rules_ from_ string parse_rules_from_stringtakes an array of rules, represented as an array of length 3 arrays holding the tag name, regex pattern, and replacement string as strings.- replace_
span_ tags replace_span_tagsreplaces the tag values of a span with a given set of rules.- replace_
trace_ tags replace_trace_tagsreplaces the tag values of all spans within a trace with a given set of rules.