pub fn parse_rules_from_string(rules: &str) -> Result<Vec<ReplaceRule>>Expand description
parse_rules_from_string takes an array of rules, represented as an array of length 3 arrays holding the tag name, regex pattern, and replacement string as strings.
- returns a vec of ReplaceRules